@@ -19,9 +19,8 @@ class SplitMixNet(nn.Module):
         y_a = self.subnet_a(x_a) * w
         y_b = self.subnet_b(x_b) * (1 - w)
 
-        return y_a, y_b, w
+        return y_a, y_b
 
     def predict(self, x_a, x_b):
-        # y_a, y_b = self.forward(x)
-        y_a, y_b, _ = self.forward(x_a, x_b)
+        y_a, y_b = self.forward(x_a, x_b)
         return torch.argmax(y_a+y_b, 1)
\ No newline at end of file
